@@ -162,6 +162,9 @@ struct _ChamplainViewPrivate
   gdouble longitude;
   gdouble latitude;
 
+  /* Timer to track time between viewport updates */
+  GTimer *update_viewport_timer;
+
   /* Hack to get smaller x,y coordinates as the clutter limit is G_MAXINT16 */
   ChamplainFloatPoint anchor;
 
@@ -198,9 +201,9 @@ struct _ChamplainViewPrivate
 
   /* Lines and shapes */
   ClutterActor *polygon_layer;  /* Contains the polygons */
+  
+  ClutterActor *layer_group;
 
-  guint update_cb_id;
-  gboolean perform_update;
   gint tiles_loading;
 };
 
@@ -269,7 +272,6 @@ static void champlain_view_go_to_with_duration (ChamplainView *view,
     gdouble latitude,
     gdouble longitude,
     guint duration);
-static gboolean perform_update_cb (ChamplainView *view);
 static gboolean fill_tile_cb (FillTileCallbackData *data);
 
 #define SCALE_HEIGHT  20
@@ -335,14 +337,11 @@ update_viewport (ChamplainView *view,
   DEBUG_LOG ()
 
   ChamplainViewPrivate *priv = view->priv;
-  gfloat old_lat, old_lon;
 
   ChamplainFloatPoint old_anchor;
 
   old_anchor.x = priv->anchor.x;
   old_anchor.y = priv->anchor.y;
-  old_lon = priv->longitude;
-  old_lat = priv->latitude;
 
   view_update_anchor (view,
       x + priv->anchor.x + priv->viewport_size.width / 2.0,
@@ -374,11 +373,8 @@ update_viewport (ChamplainView *view,
   priv->longitude = viewport_get_current_longitude (priv);
   priv->latitude = viewport_get_current_latitude (priv);
 
-  if (fabs (priv->longitude - old_lon) > 0.001)
-    g_object_notify (G_OBJECT (view), "longitude");
-
-  if (fabs (priv->latitude - old_lat) > 0.001)
-    g_object_notify (G_OBJECT (view), "latitude");
+  g_object_notify (G_OBJECT (view), "longitude");
+  g_object_notify (G_OBJECT (view), "latitude");
 }
 
 
@@ -797,8 +793,6 @@ champlain_view_dispose (GObject *object)
   ChamplainView *view = CHAMPLAIN_VIEW (object);
   ChamplainViewPrivate *priv = view->priv;
 
-  g_source_remove (priv->update_cb_id);
-
   if (priv->factory != NULL)
     {
       g_object_unref (priv->factory);
@@ -843,6 +837,12 @@ champlain_view_dispose (GObject *object)
       priv->viewport = NULL;
     }
 
+  if (priv->layer_group != NULL)
+    {
+      g_object_unref (priv->layer_group);
+      priv->layer_group = NULL;
+    }
+
   if (priv->map_layer != NULL)
     {
       g_object_unref (priv->map_layer);
@@ -864,6 +864,9 @@ champlain_view_dispose (GObject *object)
   if (priv->goto_context != NULL)
     champlain_view_stop_go_to (view);
 
+  if (priv->update_viewport_timer != NULL)
+    g_timer_destroy (priv->update_viewport_timer);
+
   G_OBJECT_CLASS (champlain_view_parent_class)->dispose (object);
 }
 
@@ -1574,8 +1577,10 @@ champlain_view_init (ChamplainView *view)
   priv->show_scale = FALSE;
   priv->scale_unit = CHAMPLAIN_UNIT_KM;
   priv->max_scale_width = 100;
-  priv->perform_update = TRUE;
   priv->tiles_loading = 0;
+  priv->update_viewport_timer = g_timer_new();
+
+  priv->layer_group = g_object_ref (clutter_group_new ());
 
   /* Setup map layer */
   priv->map_layer = g_object_ref (clutter_group_new ());
@@ -1598,16 +1603,19 @@ champlain_view_init (ChamplainView *view)
   g_signal_connect (priv->viewport, "notify::y-origin",
       G_CALLBACK (viewport_pos_changed_cb), view);
 
-  clutter_container_add_actor (CLUTTER_CONTAINER (priv->viewport),
+  clutter_container_add_actor (CLUTTER_CONTAINER (priv->layer_group),
       priv->map_layer);
-  clutter_container_add_actor (CLUTTER_CONTAINER (priv->viewport),
+  clutter_container_add_actor (CLUTTER_CONTAINER (priv->layer_group),
       priv->polygon_layer);
-  clutter_container_add_actor (CLUTTER_CONTAINER (priv->viewport),
+  clutter_container_add_actor (CLUTTER_CONTAINER (priv->layer_group),
       priv->user_layers);
 
+  clutter_container_add_actor (CLUTTER_CONTAINER (priv->viewport),
+      priv->layer_group);
+      
   clutter_actor_raise (priv->polygon_layer, priv->map_layer);
   clutter_actor_raise (priv->user_layers, priv->map_layer);
-
+  
   /* Setup finger scroll */
   priv->finger_scroll = g_object_ref (tidy_finger_scroll_new (priv->scroll_mode));
 
@@ -1644,22 +1652,11 @@ champlain_view_init (ChamplainView *view)
   /* Setup license */
   create_license (view);
 
-  priv->update_cb_id = g_timeout_add (250, (GSourceFunc) perform_update_cb, view);
-
   priv->state = CHAMPLAIN_STATE_DONE;
   g_object_notify (G_OBJECT (view), "state");
 }
 
 
-static gboolean
-perform_update_cb (ChamplainView *view)
-{
-/*  DEBUG_LOG() */
-  view->priv->perform_update = TRUE;
-  return TRUE;
-}
-
-
 static void
 viewport_pos_changed_cb (G_GNUC_UNUSED GObject *gobject,
     G_GNUC_UNUSED GParamSpec *arg1,
@@ -1676,11 +1673,10 @@ viewport_pos_changed_cb (G_GNUC_UNUSED GObject *gobject,
 
   if (fabs (x - priv->viewport_size.x) > 100 ||
       fabs (y - priv->viewport_size.y) > 100 ||
-      priv->perform_update)
+      g_timer_elapsed (priv->update_viewport_timer, NULL) > 0.25)
     {
-      priv->perform_update = FALSE;
-
       update_viewport (view, x, y);
+      g_timer_start (priv->update_viewport_timer);
     }
 }
 
@@ -2376,8 +2372,8 @@ champlain_view_remove_layer (ChamplainView *view,
  * champlain_view_get_coords_from_event:
  * @view: a #ChamplainView
  * @event: a #ClutterEvent
- * @lat: a variable where to put the latitude of the event
- * @lon: a variable where to put the longitude of the event
+ * @lat: (out): a variable where to put the latitude of the event
+ * @lon: (out): a variable where to put the longitude of the event
  *
  * Gets coordinates from button-press-event and button-release-event signals.
  *
@@ -2388,8 +2384,8 @@ champlain_view_remove_layer (ChamplainView *view,
 gboolean
 champlain_view_get_coords_from_event (ChamplainView *view,
     ClutterEvent *event,
-    gdouble *latitude,
-    gdouble *longitude)
+    gdouble *lat,
+    gdouble *lon)
 {
   DEBUG_LOG ()
 
@@ -2439,7 +2435,7 @@ champlain_view_get_coords_from_event (ChamplainView *view,
       return FALSE;
     }
 
-  return champlain_view_get_coords_at (view, x, y, latitude, longitude);
+  return champlain_view_get_coords_at (view, x, y, lat, lon);
 }
 
 
@@ -2448,8 +2444,8 @@ champlain_view_get_coords_from_event (ChamplainView *view,
  * @view: a #ChamplainView
  * @x: the x position in the view
  * @y: the y position in the view
- * @lat: a variable where to put the latitude of the event
- * @lon: a variable where to put the longitude of the event
+ * @lat: (out): a variable where to put the latitude of the event
+ * @lon: (out): a variable where to put the longitude of the event
  *
  * Gets latitude and longitude for the given x, y position in
  * the view. Use if you get coordinates from GtkEvents for example.
@@ -2462,8 +2458,8 @@ gboolean
 champlain_view_get_coords_at (ChamplainView *view,
     guint x,
     guint y,
-    gdouble *latitude,
-    gdouble *longitude)
+    gdouble *lat,
+    gdouble *lon)
 {
   DEBUG_LOG ()
 
@@ -2477,11 +2473,11 @@ champlain_view_get_coords_at (ChamplainView *view,
   rel_x = x - actor_x;
   rel_y = y - actor_y;
 
-  if (latitude)
-    *latitude = viewport_get_latitude_at (priv,
+  if (lat)
+    *lat = viewport_get_latitude_at (priv,
           priv->viewport_size.y + rel_y + priv->anchor.y);
-  if (longitude)
-    *longitude = viewport_get_longitude_at (priv,
+  if (lon)
+    *lon = viewport_get_longitude_at (priv,
           priv->viewport_size.x + rel_x + priv->anchor.x);
 
   return TRUE;
@@ -3088,7 +3084,7 @@ champlain_view_ensure_visible (ChamplainView *view,
 /**
  * champlain_view_ensure_markers_visible:
  * @view: a #ChamplainView
- * @markers: a NULL terminated array of #ChamplainMarker elements
+ * @markers: (array zero-terminated=1): a NULL terminated array of #ChamplainMarker elements
  * @animate: a #gboolean
  *
  * Changes the map's zoom level and center to make sure those markers are
@@ -3263,7 +3259,7 @@ champlain_view_get_max_zoom_level (ChamplainView *view)
  *
  * Gets the view's current map source.
  *
- * Returns: the view's current map source. If you need to keep a reference to the
+ * Returns: (transfer none): the view's current map source. If you need to keep a reference to the
  * map source then you have to call #g_object_ref.
  *
  * Since: 0.4
